@@ -21,6 +21,7 @@
 ScriptUtilClass::ScriptUtilClass()
 {
     setMethod("command", command);
+    setMethod("print", print);
     setMethod("println", println);
     setMethod("sleep", sleep);
 }
@@ -58,6 +59,16 @@ var ScriptUtilClass::command(const var::NativeFunctionArgs& a)
     return true;
 }
 
+var ScriptUtilClass::print(const var::NativeFunctionArgs& a)
+{
+    if (a.numArguments == 0) return false;
+    
+    String out = toString(a);
+    std::cout << out;
+    
+    return true;
+}
+
 var ScriptUtilClass::println(const var::NativeFunctionArgs& a)
 {
     if (a.numArguments == 0) return false;
